@@ -34,6 +34,8 @@
 
 #include <Lum/Images/Loader.h>
 
+#include <Lum/OS/Theme.h>
+
 static std::list<Hiscore*> hiscores;
 static std::wstring        userName(L"???");
 static size_t              areaWidth=16,areaHeight=16,areaBombs=40;
@@ -88,6 +90,32 @@ bool LoadConfig()
     userName=Lum::Base::StringToWString(tmp);
   }
 
+  oneButtonMode=Lum::OS::display->GetTheme()->RequestFingerFriendlyControls();
+
+  size_t boxSize=0;
+
+  if (Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+    for (std::vector<Theme>::const_iterator theme=themes.begin();
+         theme!=themes.end();
+         ++theme)  {
+      if (theme->boxSize>boxSize) {
+        themeName=L"";
+        if (theme->name.find(L"Internal")==std::wstring::npos) {
+          boxSize=theme->boxSize;
+          themeName=theme->name;
+        }
+        else if (theme->name.find(L"Internal")!=std::wstring::npos &&
+          theme->name.empty()) {
+          boxSize=theme->boxSize;
+          themeName=theme->name;
+          continue;
+        }
+      }
+    }
+  }
+
+  // TODO: Find matching theme
+
   top=Lum::Config::LoadConfigFromXMLFile(path.GetPath(),errors);
 
   if (top==NULL) {
@@ -269,11 +297,7 @@ Hiscore* GetConfig(size_t width, size_t height, size_t bombs)
 static const wchar_t* imageNames[] = {
   L"hidden.png",
   L"bomb.png",
-  L"marked.png",
-  L"left.png",
-  L"up.png",
-  L"right.png",
-  L"down.png"
+  L"marked.png"
 };
 
 bool LoadThemes()
@@ -292,6 +316,10 @@ bool LoadThemes()
     theme.boxSize=32;
     themes.push_back(theme);
 
+    theme.name=L"Internal Huge";
+    theme.boxSize=48;
+    themes.push_back(theme);
+
   // Find sub directories in the global or local theme directory that contain
   // at least one of the required images
 
@@ -327,6 +355,7 @@ bool LoadThemes()
         size_t imageCount=0;
 
         theme.name=Lum::Base::StringToWString(dirEnt->d_name);
+        theme.boxSize=0;
 
         for (size_t i=0; i<countImage; i++) {
           Lum::Base::Path path;
@@ -337,7 +366,8 @@ bool LoadThemes()
 
           if (Lum::Images::loader->Load(dirPath.GetPath(),theme.images[i])) {
             imageCount++;
-            theme.boxSize=theme.images[i]->GetWidth();
+            theme.boxSize=std::max(theme.boxSize,theme.images[i]->GetWidth());
+            theme.boxSize=std::max(theme.boxSize,theme.images[i]->GetHeight());
           }
           else {
             std::cerr << "Cannot load image '" << Lum::Base::WStringToString(dirPath.GetPath()) << "'" << std::endl;
