@@ -28,6 +28,13 @@
 
 Sweeper::Sweeper()
 : sWidth(0),sHeight(0),
+  emptyColor(0.6,0.6,0.6,Lum::OS::Display::blackColor),
+  cellColor(0.7,0.7,0.7,Lum::OS::Display::blackColor),
+  lightColor(0.95,0.95,0.95,Lum::OS::Display::blackColor),
+  darkColor(0.2,0.2,0.2,Lum::OS::Display::blackColor),
+  textColor(1,1,1,Lum::OS::Display::whiteColor),
+  bombColor(0,0,0,Lum::OS::Display::whiteColor),
+  markColor(1,0,0,Lum::OS::Display::whiteColor),
   status(new Lum::Model::ULong()),
   marks(new Lum::Model::Long()),
   bombs(0),
@@ -43,8 +50,6 @@ Sweeper::Sweeper()
 
   font=Lum::OS::display->GetFont(Lum::OS::Display::fontTypeFixed,
                                  Lum::OS::Display::fontScaleFootnote);
-
-  cellBackground=Lum::OS::display->GetFill(Lum::OS::Display::buttonBackgroundFillIndex);
 }
 
 Sweeper::~Sweeper()
@@ -52,6 +57,12 @@ Sweeper::~Sweeper()
   delete game;
 }
 
+bool Sweeper::RequiresKnobs() const
+{
+  return false;
+}
+
+
 void Sweeper::EvaluateThemeName()
 {
   for (size_t i=0; i<themes.size(); i++) {
@@ -96,6 +107,49 @@ void Sweeper::UpdateDimensions()
   }
 }
 
+void Sweeper::DrawEmptyCellBackground(Lum::OS::DrawInfo* draw,
+                                       int x, int y,
+                                       size_t w, size_t h)
+{
+  draw->PushForeground(emptyColor);
+  draw->FillRectangle(x,y,w,h);
+  draw->PopForeground();
+}
+
+void Sweeper::DrawHiddenCellBackground(Lum::OS::DrawInfo* draw,
+                                       int x, int y,
+                                       size_t w, size_t h)
+{
+  draw->PushForeground(cellColor);
+  draw->FillRectangle(x,y,w,h);
+  draw->PopForeground();
+}
+
+void Sweeper::DrawHiddenCellInternal(Lum::OS::DrawInfo* draw,
+                                     int x, int y,
+                                     size_t w, size_t h)
+{
+  draw->PushForeground(lightColor);
+  draw->DrawLine(x,y+h-1,x,y);
+  draw->DrawLine(x,y,x+w-1,y);
+  draw->PopForeground();
+
+  draw->PushForeground(lightColor);
+  draw->DrawLine(x+1,y+h-2,x+1,y);
+  draw->DrawLine(x,y+1,x+w-2,y+1);
+  draw->PopForeground();
+
+  draw->PushForeground(darkColor);
+  draw->DrawLine(x+1,y+h-1,x+w-1,y+h-1);
+  draw->DrawLine(x+w-1,y+h-1,x+w-1,y);
+  draw->PopForeground();
+
+  draw->PushForeground(darkColor);
+  draw->DrawLine(x+2,y+h-2,x+w-2,y+h-2);
+  draw->DrawLine(x+w-2,y+h-2,x+w-2,y+1);
+  draw->PopForeground();
+}
+
 void Sweeper::DrawCell(size_t row, size_t column)
 {
   size_t            x,y,frameA,frameB,frameSize;
@@ -104,13 +158,11 @@ void Sweeper::DrawCell(size_t row, size_t column)
   x=row*GetBoxSize();
   y=column*GetBoxSize();
 
-  frameA=std::max(cellBackground->leftBorder,cellBackground->topBorder);
-  frameB=std::max(cellBackground->rightBorder,cellBackground->bottomBorder);
+  frameA=4;
+  frameB=4;
   frameSize=frameA+frameB;
 
-  Lum::OS::FillRef fill=Lum::OS::display->GetFill(Lum::OS::Display::backgroundFillIndex);
-
-  fill->Draw(draw,x,y,GetBoxSize(),GetBoxSize(),x,y,GetBoxSize(),GetBoxSize());
+  DrawEmptyCellBackground(draw,x,y,GetBoxSize(),GetBoxSize());
 
   // Check if we have a filled gaming area
   if (area[row][column].active) {
@@ -122,7 +174,7 @@ void Sweeper::DrawCell(size_t row, size_t column)
           GetImage(bombImage)->Draw(draw,x,y);
         }
         else {
-          draw->PushForeground(Lum::OS::display->textColor);
+          draw->PushForeground(bombColor);
           draw->FillArc(x+frameA,
                         y+frameA,
                         GetBoxSize()-frameSize,
@@ -136,8 +188,9 @@ void Sweeper::DrawCell(size_t row, size_t column)
         // paint the number of hidden neighbours...
         if (area[row][column].count!=0) {
           std::wstring string=Lum::Base::NumberToWString((unsigned long)area[row][column].count);
-          draw->PushFont(font,Lum::OS::Font::normal);
-          draw->PushForeground(Lum::OS::display->textColor);
+
+          draw->PushFont(font);
+          draw->PushForeground(textColor);
           draw->DrawString(x+(GetBoxSize()-font->StringWidth(string,Lum::OS::Font::normal)) / 2,
                            y+(GetBoxSize()-font->height) / 2+font->ascent,
                            string);
@@ -154,7 +207,7 @@ void Sweeper::DrawCell(size_t row, size_t column)
           GetImage(bombImage)->Draw(draw,x,y);
         }
         else {
-          draw->PushForeground(Lum::OS::display->textColor);
+          draw->PushForeground(bombColor);
           draw->FillArc(x+frameA,
                         y+frameA,
                         GetBoxSize()-frameSize,
@@ -165,14 +218,15 @@ void Sweeper::DrawCell(size_t row, size_t column)
       }
       // if the cell is marked as having a bomb, do special drawing...
       else if (area[row][column].marked) {
+        DrawHiddenCellBackground(draw,x,y,GetBoxSize(),GetBoxSize());
+
         if (GetImage(markedImage)!=NULL) {
           GetImage(markedImage)->Draw(draw,x,y);
         }
         else {
-          cellBackground->Draw(draw,
-                               x,y,GetBoxSize(),GetBoxSize(),
-                               x,y,GetBoxSize(),GetBoxSize());
-          draw->PushForeground(Lum::OS::display->fillColor);
+          DrawHiddenCellInternal(draw,x,y,GetBoxSize(),GetBoxSize());
+
+          draw->PushForeground(markColor);
           draw->FillRectangle(x+frameA,
                               y+frameA,
                               GetBoxSize()-frameSize,
@@ -182,13 +236,13 @@ void Sweeper::DrawCell(size_t row, size_t column)
       }
       // draw the cell as normal hidden cell...
       else {
+        DrawHiddenCellBackground(draw,x,y,GetBoxSize(),GetBoxSize());
+
         if (GetImage(hiddenImage)!=NULL) {
           GetImage(hiddenImage)->Draw(draw,x,y);
         }
         else {
-          cellBackground->Draw(draw,
-                               x,y,GetBoxSize(),GetBoxSize(),
-                               x,y,GetBoxSize(),GetBoxSize());
+          DrawHiddenCellInternal(draw,x,y,GetBoxSize(),GetBoxSize());
         }
       }
     }
@@ -433,7 +487,7 @@ bool Sweeper::HandleMouseEvent(const Lum::OS::MouseEvent& event)
     y=(event.y-this->y+vAdjustment->GetTop()-1)/GetBoxSize();
 
     if (oneButtonMode) {
-      if ((size_t)std::abs(mbdx-event.x)>=GetBoxSize()/3 || (size_t)std::abs(mbdy-event.y)>=GetBoxSize()/3) {
+      if (GetWindow()->IsDoubleClicked()) {
         OpenField(x,y);
       }
       else {
